Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(444)

Unified Diff: components/content_settings/core/browser/cookie_settings.h

Issue 1694063002: Use GURLS instead of patterns in SetCookieSetting() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@scoping_set_content_setting
Patch Set: fix bug in android Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/content_settings/core/browser/cookie_settings.h
diff --git a/components/content_settings/core/browser/cookie_settings.h b/components/content_settings/core/browser/cookie_settings.h
index 681f04c65d96d4cc1ba7574ee6becd0d544978ed..662a368904495eff82e1103be0b2f3cd48e56973 100644
--- a/components/content_settings/core/browser/cookie_settings.h
+++ b/components/content_settings/core/browser/cookie_settings.h
@@ -77,12 +77,10 @@ class CookieSettings : public RefcountedKeyedService {
// This should only be called on the UI thread.
void SetDefaultCookieSetting(ContentSetting setting);
// Sets the cookie setting for the given patterns.
//
// This should only be called on the UI thread.
- void SetCookieSetting(const ContentSettingsPattern& primary_pattern,
- const ContentSettingsPattern& secondary_pattern,
- ContentSetting setting);
+ void SetCookieSetting(const GURL& primary_url, ContentSetting setting);
// Resets the cookie setting for the given patterns.
//
@@ -77,12 +77,10 @@ class CookieSettings : public RefcountedKeyedService {
// This should only be called on the UI thread.
void SetDefaultCookieSetting(ContentSetting setting);
- // Sets the cookie setting for the given patterns.
+ // Sets the cookie setting for the given url.
//
// This should only be called on the UI thread.

Powered by Google App Engine
This is Rietveld 408576698